==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/fio/xmlsaver.cpp <==
/*
 * $Id: xmlsaver.cpp,v 1.3 2005/02/04 17:07:41 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.3 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "xmlsaver.h"

/**
 * 󥹥ȥ饯
 */
XMLSaver::XMLSaver()
{
}

/**
 * ǥȥ饯
 */
XMLSaver::~XMLSaver()
{
}

/**
 * XMLե¸ޤ
 * 
 * @param szFile ե̾
 * @param document XMLɥ
 * @return ¸ true ᤹
 */
bool XMLSaver::save(Glib::ustring szFile, const xmlDocPtr document)
{
    int status = xmlSaveFormatFileEnc(szFile.c_str(), document, "UTF-8", 1);

    return (-1 != status);
}

/**
 * XMLʸѴޤ
 * 
 * @param document XMLɥ
 * @return ѴʸѴ˼ԤNULL᤹
 *         פˤʤäʳ˴ɬפޤ
 */
GString* XMLSaver::toString(const xmlDocPtr document)
{
    GString *result = g_string_sized_new(1024);
    
    if (!result) {
        throw "Out of Memory Error!";
    }

    int size = 0;
    xmlChar* pMem = NULL;
    
    xmlDocDumpMemory(document, &pMem, &size);

    g_string_append(result, (const char*)pMem);
    
    xmlFree(pMem);

    return result;
}

==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/fio/xmlsaver.cpp <==
/*
 * $Id: xmlsaver.cpp,v 1.4 2005/11/24 14:21:03 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.4 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "xmlsaver.h"

/**
 * 󥹥ȥ饯
 */
XMLSaver::XMLSaver()
{
}

/**
 * ǥȥ饯
 */
XMLSaver::~XMLSaver()
{
}

/**
 * XMLե¸ޤ
 * 
 * @param szFile ե̾
 * @param document XMLɥ
 * @return ¸ true ᤹
 */
bool XMLSaver::save(Glib::ustring szFile, const xmlDocPtr document)
{
    int status = xmlSaveFormatFileEnc(szFile.c_str(), document, "UTF-8", 1);

    return (-1 != status);
}

/**
 * XMLʸѴޤ
 * 
 * @param document XMLɥ
 * @return ѴʸѴ˼ԤNULL᤹
 *         פˤʤäʳ˴(g_free)ɬפޤ
 */
char* XMLSaver::toString(const xmlDocPtr document)
{
    char* result = NULL;
    GString *buffer = g_string_sized_new(1024);
    
    if (!buffer) {
        throw "Out of Memory Error!";
    }

    int size = 0;
    xmlChar* pMem = NULL;
    
    xmlDocDumpMemory(document, &pMem, &size);

    g_string_append(buffer, (const char*)pMem);
    
    xmlFree(pMem);
    
    result = (char*)buffer->str;
    g_string_free(buffer, FALSE);

    return result;
}
